pub struct ModelIdentity {
pub workload_id: String,
pub image_digests: Vec<String>,
pub kms_root_public_key: String,
}Expand description
The identity fields a ModelAttestation presents
to the policy, extracted from its info block (Decision 8).
Fields
workload_id: Stringimage_digests: Vec<String>kms_root_public_key: StringTrait Implementations
Sourceimpl Clone for ModelIdentity
impl Clone for ModelIdentity
Sourcefn clone(&self) -> ModelIdentity
fn clone(&self) -> ModelIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelIdentity
impl Debug for ModelIdentity
impl Eq for ModelIdentity
Sourceimpl PartialEq for ModelIdentity
impl PartialEq for ModelIdentity
Sourcefn eq(&self, other: &ModelIdentity) -> bool
fn eq(&self, other: &ModelIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ModelIdentity